@@ -15,16 +15,26 @@
 class meskalin
 {
 public:
+		//basic interface functions
 	void	usage(char *self);
 	int	getfreq(char *group);
 	int	getint(char *string);
+	
+		//patterns:
 	void	normal(int frequency);
 	void	flipflop(int frequency);
 	void	chasing(int frequency, char *type);
+	void	windowlicker(int frequency, char *option);
+	
+		//specials:
+	void	reset(void);
+	void	freqvar(char *type, char *pattern);
 	void	address(int address);
 	void	led(int led);
+	
+		//misc
 	void	startio(void);
-	void	reset(void);
+
 };
 
 meskalin meskalin;
